@@ -1,8 +1,8 @@
 from .common import (
     PageCut,
-    get_centered_coordinates,
     get_contours,
     get_img_from_page,
+    get_likelihood_centered_coordinates,
     get_page_and_img,
     get_reverse_pages_and_imgs,
 )
@@ -13,8 +13,15 @@ from .content_markers import (
     PositionCourtComposition,
     PositionDecisionCategoryWriter,
     PositionNotice,
+    PositionOpinion,
 )
 from .content_starter import get_start_page_pos
-from .decision_objects import Bodyline, Decision, DecisionPage, Footnote
+from .decision_objects import (
+    Bodyline,
+    Decision,
+    DecisionPage,
+    Footnote,
+    Opinion,
+)
 from .page_footer import get_footer_line_coordinates, get_page_end
 from .page_header import get_header_line, get_page_num
